#include <iostream>
#include <string>
#include <cassert>
#include <fstream>

const std::string FILENAME("trip");

std::ifstream fin(FILENAME + ".in");
std::ofstream fout(FILENAME + ".out");

const int MaxN = 2e5 + 5;
const int MaxLog = 20;

int arr[MaxN], pref[MaxN];

int char_to_int(char ch) {
    if (ch == 'o') return 1;
    if (ch == '-') return 0;
    if (ch == 'x') return -1;
    return 0;
}

namespace rmq {
    int rminq[MaxLog][MaxN];
    int rmaxq[MaxLog][MaxN];
    int log_2[MaxN];

    void build_logs(int n) {
        log_2[1] = 0;
        for (int i = 2; i <= n; ++i)
            log_2[i] = log_2[i >> 1] + 1;
    }

    void build(int n, int* arr) {
        if (!log_2[n])
            build_logs(n);

        for (int i = 1; i <= n; ++i) {
            rminq[0][i] = rmaxq[0][i] = arr[i];
        }

        for (int p = 1; (1 << p) <= n; ++p) {
            for (int i = 1; i + (1 << p) - 1 <= n; ++i) {
                rminq[p][i] = std::min(rminq[p - 1][i], rminq[p - 1][i + (1 << (p - 1))]);
                rmaxq[p][i] = std::max(rmaxq[p - 1][i], rmaxq[p - 1][i + (1 << (p - 1))]);
            }
        }
    }

    std::pair<int,int> query(int l, int r) {
        int p = log_2[r - l + 1]; 
        int range_min = std::min(rminq[p][std::max(l, 1)], rminq[p][r - (1 << p) + 1]);
        int range_max = std::max(rmaxq[p][std::max(l, 1)], rmaxq[p][r - (1 << p) + 1]);

        if (l == 0) {
            range_min = std::min(range_min, 0);
            range_max = std::max(range_max, 0);
        }
        return {range_min, range_max};
    }
};

void compute_pref(int n, int* arr, int* pref) {
    for (int i = 1; i <= n; ++i) {
        pref[i] = pref[i - 1] + arr[i];
    }
}

int main() {
    int n, q;
    fin >> n;

    for (int i = 1; i <= n; ++i) {
        char ch;
        fin >> ch;
        arr[i] = char_to_int(ch);
    }
    compute_pref(n, arr, pref);
    rmq::build(n, pref);

    fin >> q;

    while (q--) {
        int type;
        fin >> type;
        if (type == 1) {
            int position;
            char  cvalue;
            fin >> position >> cvalue;
            int value  = char_to_int(cvalue);
            arr[position] = value;
            compute_pref(n, arr, pref);
            rmq::build(n, pref);
        } else {
            int l1, r1, l2, r2, k;
            fin >> l1 >> r1 >> l2 >> r2 >> k;
            
            std::pair<int,int> left_range = rmq::query(l1 - 1, r1 - 1);
            std::pair<int,int> right_range = rmq::query(l2, r2);

            int min_diff = right_range.first - left_range.second;
            int max_diff = right_range.second - left_range.first;
           
            fout << (min_diff <= k && k <= max_diff) << '\n';
        }
    }
    fin.close();
    fout.close();
    return 0;

}